import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { GetOrdersSettingsResponse, OrdersSettings, UpdateOrdersSettingsResponse, OrdersSettingsUpdatedEnvelope } from './index.typings.js';
export { ActionEvent, BaseEventMetadata, DeleteOrdersSettingsRequest, DeleteOrdersSettingsResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GetOrdersSettingsRequest, IdentificationData, IdentificationDataIdOneOf, InventoryUpdateTrigger, ListOrdersSettingsRequest, ListOrdersSettingsResponse, MessageEnvelope, RestoreInfo, UpdateOrdersSettingsRequest, WebhookIdentityType } from './index.typings.js';

type OrdersSettingsNonNullablePaths = `inventoryUpdateTrigger`;
declare function getOrdersSettings$1(httpClient: HttpClient): GetOrdersSettingsSignature;
interface GetOrdersSettingsSignature {
    /**
     * Retrieves the sites' order settings.
     *
     *
     * The `getOrdersSettings()` function returns a Promise that resolves to orders settings.
     * @returns The requested orders settings.
     */
    (): Promise<NonNullablePaths<GetOrdersSettingsResponse, {
        [P in OrdersSettingsNonNullablePaths]: `ordersSettings.${P}`;
    }[OrdersSettingsNonNullablePaths]>>;
}
declare function updateOrdersSettings$1(httpClient: HttpClient): UpdateOrdersSettingsSignature;
interface UpdateOrdersSettingsSignature {
    /**
     * Updates the sites' orders settings.
     *
     *
     * The `updateOrdersSettings()` function returns a Promise that resolves to the newly updated orders settings.
     * @param - Orders settings to update.
     * @returns The updated orders settings.
     */
    (ordersSettings: OrdersSettings): Promise<NonNullablePaths<UpdateOrdersSettingsResponse, {
        [P in OrdersSettingsNonNullablePaths]: `ordersSettings.${P}`;
    }[OrdersSettingsNonNullablePaths]>>;
}
declare const onOrdersSettingsUpdated$1: EventDefinition<OrdersSettingsUpdatedEnvelope, "wix.ecom.v1.orders_settings_updated">;

declare const getOrdersSettings: MaybeContext<BuildRESTFunction<typeof getOrdersSettings$1> & typeof getOrdersSettings$1>;
declare const updateOrdersSettings: MaybeContext<BuildRESTFunction<typeof updateOrdersSettings$1> & typeof updateOrdersSettings$1>;
/**
 * Triggered when orders settings are updated.
 */
declare const onOrdersSettingsUpdated: BuildEventDefinition<typeof onOrdersSettingsUpdated$1>;

export { GetOrdersSettingsResponse, OrdersSettings, OrdersSettingsUpdatedEnvelope, UpdateOrdersSettingsResponse, getOrdersSettings, onOrdersSettingsUpdated, updateOrdersSettings };
