import { GetOrdersSettingsRequest as GetOrdersSettingsRequest$1, GetOrdersSettingsResponse as GetOrdersSettingsResponse$1, UpdateOrdersSettingsRequest as UpdateOrdersSettingsRequest$1, UpdateOrdersSettingsResponse as UpdateOrdersSettingsResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface OrdersSettings {
    /**
     * Defines when to update the store inventory.
     * Default: `ON_ORDER_PLACED`
     */
    inventoryUpdateTrigger?: InventoryUpdateTriggerWithLiterals;
    /**
     * Whether to automatically create invoices for every new order paid online.
     * <br>
     * Default: `false`
     * <br>
     * **Note**: The issued invoice for an order is not a tax invoice and doesn't reflect refunds. You are responsible for ensuring that invoices you issue conform to any relevant legal requirements.
     */
    createInvoice?: boolean | null;
    /**
     * Date and time the orders settings were created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the orders settings were updated.
     * @readonly
     */
    updatedDate?: Date | null;
}
declare enum InventoryUpdateTrigger {
    UNKNOWN_INVENTORY_UPDATE_TRIGGER = "UNKNOWN_INVENTORY_UPDATE_TRIGGER",
    /** Stock quantities will update only after the payment is approved. */
    ON_ORDER_PAID = "ON_ORDER_PAID",
    /** Stock quantities will update while the payment is being processed. If the payment did not go through, items will restock. */
    ON_ORDER_PLACED = "ON_ORDER_PLACED"
}
/** @enumType */
type InventoryUpdateTriggerWithLiterals = InventoryUpdateTrigger | 'UNKNOWN_INVENTORY_UPDATE_TRIGGER' | 'ON_ORDER_PAID' | 'ON_ORDER_PLACED';
interface GetOrdersSettingsRequest {
}
interface GetOrdersSettingsResponse {
    /** Orders settings. */
    ordersSettings?: OrdersSettings;
}
interface UpdateOrdersSettingsRequest {
    /** Orders settings to update. */
    ordersSettings: OrdersSettings;
}
interface UpdateOrdersSettingsResponse {
    /** The updated orders settings. */
    ordersSettings?: OrdersSettings;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getOrdersSettings(): __PublicMethodMetaInfo<'GET', {}, GetOrdersSettingsRequest$1, GetOrdersSettingsRequest, GetOrdersSettingsResponse$1, GetOrdersSettingsResponse>;
declare function updateOrdersSettings(): __PublicMethodMetaInfo<'PATCH', {}, UpdateOrdersSettingsRequest$1, UpdateOrdersSettingsRequest, UpdateOrdersSettingsResponse$1, UpdateOrdersSettingsResponse>;

export { type __PublicMethodMetaInfo, getOrdersSettings, updateOrdersSettings };
